A mock trait dataset using four trait classes specified in traits
to infer feeding interactions
A mock trait dataset using four trait classes specified in traits
to infer feeding interactions
Format
feeding_rules
A data frame with 7,240 rows and 60 columns:
- trait_type_resource
broader resource trait class - i.e. column name in traits
- trait_resource
specific resource trait class - i.e. row entry in trait column
- trait_type_consumer
broader consumer trait class - i.e. column name in traits
- trait_consumer
specific consumer trait class - i.e. row entry in trait column
...
feeding_rules
A data frame with 7,240 rows and 60 columns:
- trait_type_resource
broader resource trait class - i.e. column name in traits
- trait_resource
specific resource trait class - i.e. row entry in trait column
- trait_type_consumer
broader consumer trait class - i.e. column name in traits
- trait_consumer
specific consumer trait class - i.e. row entry in trait column
...